@@ -471,8 +471,8 @@ class _DxFileToNxConverter(BaseConverter):
             self._path_nxtomo_attrs(root_grp)
 
     def _path_nxtomo_attrs(self, root_grp):
-        root_grp.attrs["NX_class"] = u"NXentry"
-        root_grp.attrs["definition"] = u"NXtomo"
+        root_grp.attrs["NX_class"] = "NXentry"
+        root_grp.attrs["definition"] = "NXtomo"
         root_grp.attrs["version"] = converter_version()
         root_grp.attrs["default"] = "instrument/detector"
         instrument_grp = root_grp.require_group("instrument")
@@ -486,7 +486,7 @@ class _DxFileToNxConverter(BaseConverter):
         if "data" in detector_grp:
             detector_grp["data"].attrs["interpretation"] = "image"
         sample_node = root_grp.require_group("sample")
-        sample_node.attrs["NX_class"] = u"NXsample"
+        sample_node.attrs["NX_class"] = "NXsample"
 
     def _convert_frames_without_duplication(self):
         image_key = []
