@@ -273,7 +273,7 @@ def edf_to_nx(
         )
         if distance is not None:
             h5d["/entry/instrument/detector/distance"] = distance
-            h5d["/entry/instrument/detector/distance"].attrs["unit"] = u"m"
+            h5d["/entry/instrument/detector/distance"].attrs["unit"] = "m"
 
         pixel_size = scan.retrieve_information(
             scan=os.path.abspath(scan.path),
@@ -285,11 +285,11 @@ def edf_to_nx(
         h5d["/entry/instrument/detector/x_pixel_size"] = (
             pixel_size * metricsystem.millimeter.value
         )
-        h5d["/entry/instrument/detector/x_pixel_size"].attrs["unit"] = u"m"
+        h5d["/entry/instrument/detector/x_pixel_size"].attrs["unit"] = "m"
         h5d["/entry/instrument/detector/y_pixel_size"] = (
             pixel_size * metricsystem.millimeter.value
         )
-        h5d["/entry/instrument/detector/y_pixel_size"].attrs["unit"] = u"m"
+        h5d["/entry/instrument/detector/y_pixel_size"].attrs["unit"] = "m"
 
         energy = scan.retrieve_information(
             scan=os.path.abspath(scan.path),
@@ -300,7 +300,7 @@ def edf_to_nx(
         )
         if energy is not None:
             h5d["/entry/instrument/beam/incident_energy"] = energy
-            h5d["/entry/instrument/beam/incident_energy"].attrs["unit"] = u"keV"
+            h5d["/entry/instrument/beam/incident_energy"].attrs["unit"] = "keV"
 
         # rotations values
         rotation_dataset = h5d.create_dataset(
@@ -590,13 +590,13 @@ def edf_to_nx(
             )
 
         # we can add some more NeXus look and feel
-        h5d["/entry"].attrs["NX_class"] = u"NXentry"
-        h5d["/entry"].attrs["definition"] = u"NXtomo"
+        h5d["/entry"].attrs["NX_class"] = "NXentry"
+        h5d["/entry"].attrs["definition"] = "NXtomo"
         h5d["/entry"].attrs["version"] = converter_version()
-        h5d["/entry/instrument"].attrs["NX_class"] = u"NXinstrument"
-        h5d["/entry/instrument/detector"].attrs["NX_class"] = u"NXdetector"
-        h5d["/entry/instrument/detector/data"].attrs["interpretation"] = u"image"
-        h5d["/entry/sample"].attrs["NX_class"] = u"NXsample"
+        h5d["/entry/instrument"].attrs["NX_class"] = "NXinstrument"
+        h5d["/entry/instrument/detector"].attrs["NX_class"] = "NXdetector"
+        h5d["/entry/instrument/detector/data"].attrs["interpretation"] = "image"
+        h5d["/entry/sample"].attrs["NX_class"] = "NXsample"
         h5d["/entry/definition"] = "NXtomo"
         source_grp = h5d["/entry/instrument"].get("source", None)
         if source_grp is not None and "NX_class" not in source_grp.attrs:
