@@ -421,7 +421,7 @@ class BaseAcquisition:
         else:
             mess += "default value will be set. (0)"
             _logger.warning(mess)
-            return 0, "m"
+            return [0] * n_frame, "m"
 
     def _get_y_translation(self, root_node, n_frame) -> tuple:
         """return the list of translation for each frame"""
@@ -449,7 +449,7 @@ class BaseAcquisition:
         else:
             mess += "default value will be set. (0)"
             _logger.warning(mess)
-            return 0, "m"
+            return [0] * n_frame, "m"
 
     @staticmethod
     def get_z_translation_frm(root_node, n_frame: int, configuration: TomoHDF5Config):
@@ -477,7 +477,7 @@ class BaseAcquisition:
         else:
             mess += "default value will be set. (0)"
             _logger.warning(mess)
-            return 0, "m"
+            return [0] * n_frame, "m"
 
     def _get_z_translation(self, root_node, n_frame) -> tuple:
         """return the list of translation for each frame"""
