@@ -82,7 +82,8 @@ H5_DARK_TITLES = Tomo.H5.DARK_TITLES
 H5_INIT_TITLES = Tomo.H5.INIT_TITLES
 H5_ZSERIE_INIT_TITLES = Tomo.H5.ZSERIE_INIT_TITLES
 H5_PROJ_TITLES = Tomo.H5.PROJ_TITLES
-H5_REF_TITLES = Tomo.H5.REF_TITLES
+H5_FLAT_TITLES = Tomo.H5.FLAT_TITLES
+H5_REF_TITLES = H5_FLAT_TITLES
 H5_Y_ROT_KEY = Tomo.H5.Y_ROT_KEY
 H5_DIODE_KEYS = Tomo.H5.DIODE_KEYS
 
@@ -90,7 +91,7 @@ DEFAULT_SCAN_TITLES = H5ScanTitles(
     H5_INIT_TITLES,
     H5_ZSERIE_INIT_TITLES,
     H5_DARK_TITLES,
-    H5_REF_TITLES,
+    H5_FLAT_TITLES,
     H5_PROJ_TITLES,
     H5_ALIGNMENT_TITLES,
 )
@@ -237,6 +238,8 @@ class _H5ToNxConverter(BaseConverter):
 
         :return:
         """
+        self.configuration.check_tomo_n = False
+        # when building from urls `tomo_n` has no meaning
         if self.configuration.is_using_titles:
             raise ValueError("Configuration specify that titles should be used")
         if self.configuration.format is None:
@@ -362,9 +365,18 @@ class _H5ToNxConverter(BaseConverter):
             for group_name in groups:
                 _logger.debug("parse {}".format(group_name))
                 entry = h5d[group_name]
+                # improve handling of External (this is the case of proposal files)
+                if isinstance(h5d.get(group_name, getlink=True), h5py.ExternalLink):
+                    external_link = h5d.get(group_name, getlink=True)
+                    file_path = external_link.filename
+                    data_path = external_link.path
+                else:
+                    file_path = self.configuration.input_file
+                    data_path = entry.name
+
                 url = DataUrl(
-                    file_path=self.configuration.input_file,
-                    data_path=entry.name,
+                    file_path=file_path,
+                    data_path=data_path,
                     scheme="silx",
                     data_slice=None,
                 )
@@ -515,7 +527,6 @@ class _H5ToNxConverter(BaseConverter):
         return False
 
     def write(self):
-        # TODO: should be split into different parts as well
         res = []
         possible_extensions = (".hdf5", ".h5", ".nx", ".nexus")
         output_file_basename = os.path.basename(self.configuration.output_file)
@@ -532,7 +543,7 @@ class _H5ToNxConverter(BaseConverter):
         _logger.debug("\n   - ".join(acq_str))
         if len(self.acquisitions) == 0:
             _logger.warning(
-                "Not valid acquisitions have been found. Maybe no "
+                "No valid acquisitions have been found. Maybe no "
                 "init (zserie) titles have been found. You can "
                 "provide more."
             )
@@ -757,7 +768,7 @@ def h5_to_nx(
     configuration.init_titles = scan_titles.init_titles
     configuration.zserie_init_titles = scan_titles.init_zserie_titles
     configuration.dark_titles = scan_titles.dark_titles
-    configuration.flat_titles = scan_titles.ref_titles
+    configuration.flat_titles = scan_titles.flat_titles
     configuration.projections_titles = scan_titles.proj_titles
     configuration.alignment_titles = scan_titles.align_titles
 
@@ -793,7 +804,11 @@ def from_h5_to_nx(
 
 
 def get_bliss_tomo_entries(input_file_path: str, configuration: TomoHDF5Config):
-    """Util function. Used by tomwer for example"""
+    """Util function.
+    Return the set of entries at root that match bliss entries.
+    Used by tomwer for example.
+    Warning: entries can be external links (in the case of the file beeing a proposal file)
+    """
     if not isinstance(configuration, TomoHDF5Config):
         raise TypeError("configuration is expected to be a HDF5Config")
 
@@ -803,15 +818,22 @@ def get_bliss_tomo_entries(input_file_path: str, configuration: TomoHDF5Config):
         for group_name in h5d.keys():
             _logger.debug("parse %s" % group_name)
             entry = h5d[group_name]
-            data_path = entry.name
-            if not data_path.startswith("/"):
-                data_path = "/" + data_path
-            url = DataUrl(file_path=input_file_path, data_path=data_path)
+            # improve handling of External (this is the case of proposal files)
+            if isinstance(h5d.get(group_name, getlink=True), h5py.ExternalLink):
+                external_link = h5d.get(group_name, getlink=True)
+                file_path = external_link.filename
+                data_path = external_link.path
+            else:
+                file_path = input_file_path
+                data_path = entry.name
+                if not data_path.startswith("/"):
+                    data_path = "/" + data_path
+            url = DataUrl(file_path=file_path, data_path=data_path)
             if configuration.is_using_titles:
                 # if use title take the ones corresponding to init
                 entry_type = get_entry_type(url=url, configuration=configuration)
                 if entry_type is AcquisitionStep.INITIALIZATION:
-                    acquisitions.append(entry.name)
+                    acquisitions.append(group_name)
             else:
                 # check if the entry fit one of the data_frame_grps
                 # with an init status
