@@ -53,7 +53,7 @@ H5ScanTitles = namedtuple(
         "init_titles",
         "init_zserie_titles",
         "dark_titles",
-        "ref_titles",
+        "flat_titles",
         "proj_titles",
         "align_titles",
     ],
