@@ -192,7 +192,9 @@ class TomoHDF5Config:
 
     DARK_TITLES_DK = "dark_titles"
 
-    REF_TITLES_DK = "ref_titles"
+    FLAT_TITLES_DK = "flat_titles"
+
+    FLAT_TILES_ALIASES = ("ref_titles",)
 
     PROJ_TITLES_DK = "proj_titles"
 
@@ -213,7 +215,7 @@ class TomoHDF5Config:
         INIT_TITLES_DK: "List of title to consider the group/entry as a initialization (sequence start). Ignored if dark_groups, flat_groups, projection_groups ... are provided.",
         ZSERIE_INIT_TITLES_DK: "List of title to consider the group/entry as a zserie initialization (sequence start). Ignored if dark_groups, flat_groups, projection_groups ... are provided.",
         DARK_TITLES_DK: "List of title to consider the group/entry as a dark.  Ignored if dark_groups, flat_groups, projection_groups ... are provided.",
-        REF_TITLES_DK: "List of title to consider the group/entry as a reference / flat.  Ignored if dark_groups, flat_groups, projection_groups ... are provided.",
+        FLAT_TITLES_DK: "List of title to consider the group/entry as a reference / flat.  Ignored if dark_groups, flat_groups, projection_groups ... are provided.",
         PROJ_TITLES_DK: "List of title to consider the group/entry as a projection.  Ignored if dark_groups, flat_groups, projection_groups ... are provided.",
         ALIGNMENT_TITLES_DK: "List of title to consider the group/entry as an alignment.  Ignored if dark_groups, flat_groups, projection_groups ... are provided.",
         X_PIXEL_SIZE_KEYS_DK: "List of keys / paths to look for the x pixel size",
@@ -254,22 +256,41 @@ class TomoHDF5Config:
 
     EXTRA_PARAMS_SECTION_DK = "EXTRA_PARAMS_SECTION"
 
-    EXTRA_PARAMS_ENERGY_DK = "energy"
-    EXTRA_PARAMS_X_PIXEL_SIZE_DK = "x_pixel_size"
-    EXTRA_PARAMS_Y_PIXEL_SIZE_DK = "y_pixel_size"
-    EXTRA_PARAMS_DISTANCE = "detector_sample_distance"
+    EXTRA_PARAMS_ENERGY_DK = "energy_kev"
+    EXTRA_PARAMS_ENERGY_DK_ALIASES = ("energy",)
+    EXTRA_PARAMS_X_PIXEL_SIZE_DK = "x_pixel_size_m"
+    EXTRA_PARAMS_X_PIXEL_SIZE_DK_ALIASES = ("x_pixel_size",)
+    EXTRA_PARAMS_Y_PIXEL_SIZE_DK = "y_pixel_size_m"
+    EXTRA_PARAMS_Y_PIXEL_SIZE_DK_ALIASES = ("y_pixel_size",)
+    EXTRA_PARAMS_DISTANCE = "detector_sample_distance_m"
+    EXTRA_PARAMS_DISTANCE_ALIASES = ("detector_sample_distance",)
 
-    EXTRA_PARAMS_ENERGY_VALID_KEYS = (
+    EXTRA_PARAMS_ENERGY_DEFAULT_VALID_KEYS = (
         EXTRA_PARAMS_ENERGY_DK,
         EXTRA_PARAMS_X_PIXEL_SIZE_DK,
         EXTRA_PARAMS_Y_PIXEL_SIZE_DK,
         EXTRA_PARAMS_DISTANCE,
     )
 
+    EXTRA_PARAMS_ENERGY_VALID_KEYS = (
+        *EXTRA_PARAMS_ENERGY_DEFAULT_VALID_KEYS,
+        *EXTRA_PARAMS_ENERGY_DK_ALIASES,
+        *EXTRA_PARAMS_X_PIXEL_SIZE_DK_ALIASES,
+        *EXTRA_PARAMS_Y_PIXEL_SIZE_DK_ALIASES,
+        *EXTRA_PARAMS_DISTANCE_ALIASES,
+    )
+
+    EXTRA_PARAMS_ALIASES = {
+        EXTRA_PARAMS_ENERGY_DK: EXTRA_PARAMS_ENERGY_DK_ALIASES,
+        EXTRA_PARAMS_X_PIXEL_SIZE_DK: EXTRA_PARAMS_X_PIXEL_SIZE_DK_ALIASES,
+        EXTRA_PARAMS_Y_PIXEL_SIZE_DK: EXTRA_PARAMS_Y_PIXEL_SIZE_DK_ALIASES,
+        EXTRA_PARAMS_DISTANCE: EXTRA_PARAMS_DISTANCE_ALIASES,
+    }
+
     COMMENTS_EXTRA_PARAMS_SECTION = {
         EXTRA_PARAMS_SECTION_DK: "optional section\n"
         "# you can predefined values which are missing in the input .h5 file\n"
-        "# Handled parameters are {}".format(EXTRA_PARAMS_ENERGY_VALID_KEYS)
+        "# Handled parameters are {}".format(EXTRA_PARAMS_ENERGY_DEFAULT_VALID_KEYS)
     }
 
     COMMENTS = COMMENTS_GENERAL_SECTION
@@ -308,7 +329,7 @@ class TomoHDF5Config:
         self._init_titles = settings.Tomo.H5.INIT_TITLES
         self._zserie_init_titles = settings.Tomo.H5.ZSERIE_INIT_TITLES
         self._dark_titles = settings.Tomo.H5.DARK_TITLES
-        self._flat_titles = settings.Tomo.H5.REF_TITLES
+        self._flat_titles = settings.Tomo.H5.FLAT_TITLES
         self._projection_titles = settings.Tomo.H5.PROJ_TITLES
         self._alignment_titles = settings.Tomo.H5.ALIGNMENT_TITLES
         self._x_pixel_size_paths = settings.Tomo.H5.X_PIXEL_SIZE
@@ -318,6 +339,9 @@ class TomoHDF5Config:
         self._data_grps_urls = tuple()
         self._default_copy_behavior = False
 
+        # should we check for tomo_n contain in the init sequence
+        self._check_tomo_n = True
+
         # extra options
         self._param_already_defined = {}
 
@@ -791,6 +815,16 @@ class TomoHDF5Config:
         """
         return not (len(self.data_frame_grps) == 0)
 
+    @property
+    def check_tomo_n(self):
+        return self._check_tomo_n
+
+    @check_tomo_n.setter
+    def check_tomo_n(self, check: bool):
+        if not isinstance(check, bool):
+            raise TypeError("'check' is expected to be a boolean")
+        self._check_tomo_n = check
+
     def clear_titles(self):
         """
         set all titles to empty tuple
@@ -845,7 +879,7 @@ class TomoHDF5Config:
                 TomoHDF5Config.INIT_TITLES_DK: self.init_titles or "",
                 TomoHDF5Config.ZSERIE_INIT_TITLES_DK: self.zserie_init_titles or "",
                 TomoHDF5Config.DARK_TITLES_DK: self.dark_titles or "",
-                TomoHDF5Config.REF_TITLES_DK: self.flat_titles or "",
+                TomoHDF5Config.FLAT_TITLES_DK: self.flat_titles or "",
                 TomoHDF5Config.PROJ_TITLES_DK: self.projections_titles or "",
                 TomoHDF5Config.ALIGNMENT_TITLES_DK: self.alignment_titles or "",
             },
@@ -1060,10 +1094,30 @@ class TomoHDF5Config:
             dark_titles = convert_str_to_tuple(dark_titles, none_if_empty=True)
             self.dark_titles = dark_titles
         # handle ref titles. empty string is consider as a valid value
-        flat_titles = dict_.get(TomoHDF5Config.REF_TITLES_DK, None)
-        if flat_titles is not None:
-            flat_titles = convert_str_to_tuple(flat_titles, none_if_empty=True)
-            self.flat_titles = flat_titles
+        flat_titles_dks = [
+            TomoHDF5Config.FLAT_TITLES_DK,
+        ]
+        flat_titles_dks.extend(TomoHDF5Config.FLAT_TILES_ALIASES)
+        flat_title_key_picked = None
+        ## handle flat titles
+        for alias in flat_titles_dks:
+            flat_titles = dict_.get(alias, None)
+            if flat_titles is not None:
+                if flat_title_key_picked is not None:
+                    _logger.warning(
+                        f"flat titles are provided twice under {flat_title_key_picked} and {alias}. Please clean your configuration file. {flat_title_key_picked} will be used"
+                    )
+                else:
+                    flat_titles = convert_str_to_tuple(flat_titles, none_if_empty=True)
+                    self.flat_titles = flat_titles
+                    flat_title_key_picked = alias
+        if (
+            flat_title_key_picked is not None
+            and flat_title_key_picked != TomoHDF5Config.FLAT_TITLES_DK
+        ):
+            _logger.warning(
+                f"{flat_title_key_picked} will be removed in the future. Please use {TomoHDF5Config.FLAT_TITLES_DK} instead"
+            )
         # handle projection titles. empty string is consider as a valid value
         proj_titles = dict_.get(TomoHDF5Config.PROJ_TITLES_DK, None)
         if proj_titles is not None:
